@@ -3,6 +3,7 @@ import base64
 import hashlib
 from Crypto.Cipher import AES
 
+
 def encrypt(raw, key):
     cipher = AES.new(_hash_key(key=key), AES.MODE_ECB)
     padded = _pad(raw)
@@ -10,6 +11,7 @@ def encrypt(raw, key):
     encoded = base64.b64encode(encrypted)
     return encoded
 
+
 def decrypt(encoded, key):
     cipher = AES.new(_hash_key(key=key), AES.MODE_ECB)
     encrypted = base64.b64decode(encoded)
@@ -22,7 +24,16 @@ def _hash_key(key, size=16):
     hashed_key = hashlib.sha1(key)
     return hashed_key.digest()[:size]
 
+
 def _pad(text, size=16):
-    return text + (size - len(text) % size) * chr(size - len(text) % size)
+    if isinstance(text, bytes):
+        text_len = len(text) % size
+    else:
+        text_len = len(text.encode('utf-8')) % size
+    return text + (size - text_len) * chr(size - text_len)
+
+
 def _unpad(text):
-    return text[0:-ord(text[-1])]
\ No newline at end of file
+    if isinstance(text, bytes):
+        text = text.decode('utf-8')
+    return text[0:-ord(text[-1])]
